@@ -5,12 +5,12 @@ def get_td_Home():
     # Returns the path where this file is stored
     return os.path.realpath(__file__).strip("data_utils.py")
 
-def read_rna_file(rna_file_path, identifier='hugo', fetch_missing_hugo=False):
+def read_rna_file(file_path, identifier='hugo', fetch_missing_hugo=False):
     """
     Read in a cbioportal pancancer or TCGA Xena Hug txt file containing mixture gene expression data, and return a pandas dataframe.
     Columns are patients, Rows are genes
     Inputs:
-        - rna_file_path: string. Relative or full path to the RNA seq file
+        - file_path: string. Relative or full path to the RNA seq file
             This file is tab seperated and includes two columns, 'Hugo_Symbol' and 'Entrez_Gene_Id', for each
             gene preceding the expression values for each patient
         - identifier: string. Determines which gene identifier to use to index the rna data.
@@ -25,7 +25,7 @@ def read_rna_file(rna_file_path, identifier='hugo', fetch_missing_hugo=False):
     import pandas as pd
     from TumorDecon.hugoify import hugo
 
-    rna = pd.read_csv(rna_file_path,  sep='\t')
+    rna = pd.read_csv(file_path,  sep='\t')
 
     # Xena Hub:
     if "sample" in rna.columns:
@@ -51,8 +51,7 @@ def read_rna_file(rna_file_path, identifier='hugo', fetch_missing_hugo=False):
         raise ReadError("Data Format not recognized")
 
     # Drop duplicate genes:
-    # remove duplicates:
-    # rna = rna.loc[~rna.index.duplicated(keep='first')] # argument keep = first, last, max, mean
+    rna = rna.loc[~rna.index.duplicated(keep='first')] # argument keep = first, last, max, mean
 
     # Drop NA (if any):
     rna.dropna(axis=0, how='any', inplace=True)
@@ -61,13 +60,14 @@ def read_rna_file(rna_file_path, identifier='hugo', fetch_missing_hugo=False):
     return rna
 
 
-def download_by_name(source, type, fetch_missing_hugo=True):
+def download_by_name(source, type, download_to=get_td_Home()+"data/downloaded/", fetch_missing_hugo=False,):
     """
     Function to download TCGA data from either UCSC Xena Hub or cBioPortal given
     the desired source and cancer type, instead of a URL.
         Inputs:
             - source: either "xena" or "cbio"
             - type: specific strings. Each will be presented as options in a dropdown menu in the GUI
+            - download_to: String. Directory to save downloaded data to. Default is the data/downloads folder within the package library
             - fetch_missing_hugo: boolean. Whether to fetch missing Hugo Symbols (by Entrez Gene ID) from ncbi website
         Outputs:
             - pandas df of mixture data
@@ -85,7 +85,7 @@ def download_by_name(source, type, fetch_missing_hugo=True):
         else:
             raise ValueError("type {!r} not available from UCSC Xena".format(type))
         # Download and return:
-        data = download_from_xena(url="https://tcga-xena-hub.s3.us-east-1.amazonaws.com/latest/TCGA."+urlcode+".sampleMap/HiSeqV2.gz", fetch_missing_hugo=fetch_missing_hugo)
+        data = download_from_xena(url="https://tcga-xena-hub.s3.us-east-1.amazonaws.com/download/TCGA."+urlcode+".sampleMap/HiSeqV2.gz", save_location=download_to, fetch_missing_hugo=fetch_missing_hugo)
         return data
     elif source in ["cbio", "CbioPortal", "cbioportal", "cBioPortal"]:
         type_dict = {'Acute Myeloid Leukemia':'laml','Adrenocortical Carcinoma':'acc', 'Bladder Urothelial Carcinoma':'blca', 'Brain Lower Grade Glioma':'lgg', 'Breast Invasive Carcinoma':'brca',
@@ -99,7 +99,7 @@ def download_by_name(source, type, fetch_missing_hugo=True):
         else:
             raise ValueError("type {!r} not available from CbioPortal".format(type))
         # Download and return:
-        data = download_from_cbio(url="https://cbioportal-datahub.s3.amazonaws.com/"+urlcode+"_tcga_pan_can_atlas_2018.tar.gz", fetch_missing_hugo=fetch_missing_hugo)
+        data = download_from_cbio(url="https://cbioportal-datahub.s3.amazonaws.com/"+urlcode+"_tcga_pan_can_atlas_2018.tar.gz", save_location=download_to, fetch_missing_hugo=fetch_missing_hugo)
         return data
     else:
         raise ValueError("source ({!r}) must be 'xena' or 'cbioportal'".format(source))
@@ -122,23 +122,31 @@ def download_from_cbio(url="https://cbioportal-datahub.s3.amazonaws.com/uvm_tcga
     import os
 
     # Check if file already downloaded, if not, download it:
-    file = save_location+url.replace('https://cbioportal-datahub.s3.amazonaws.com/','')
+    file = save_location+url.replace('https://cbioportal-datahub.s3.amazonaws.com','')
     if not os.path.exists(file):
         # Download file and save it locally:
-        print("Downloading data from cbioportal...")
+        print("Downloading data from cbioportal to "+file+"...")
         wget.download(url, save_location)
+        print()
+    else:
+        print("Data already exists in "+file+" - using this file (remove or rename in order to re-download).")
+        print()
     # Unzip if applicable
     folder = file.replace(".tar.gz","")
-    if file.endswith("tar.gz") and not os.path.exists(folder):
+    if file.endswith("tar.gz"): 
         tar = tarfile.open(file, "r:gz")
-        tar.extract(folder.split("/")[-1]+"/data_RNA_Seq_v2_expression_median.txt", path=save_location)
-        # tar.extractall(folder.strip(".tar.gz"))
+        try:
+            tar.extract(folder.split("/")[-1]+"/data_RNA_Seq_v2_expression_median.txt", path=save_location)
+            return read_rna_file(folder+"/data_RNA_Seq_v2_expression_median.txt", fetch_missing_hugo=fetch_missing_hugo)
+        except:
+            try:
+                tar.extract(folder.split("/")[-1]+"/data_mrna_seq_v2_rsem.txt", path=save_location)
+                return read_rna_file(folder+"/data_mrna_seq_v2_rsem.txt", fetch_missing_hugo=fetch_missing_hugo)
+            except FileNotFoundError as error:
+                print("RNA Seq Data not found in archive")
         tar.close()
-    # Read in data:
-    return read_rna_file(folder+"/data_RNA_Seq_v2_expression_median.txt", fetch_missing_hugo=fetch_missing_hugo)
 
-
-def download_from_xena(url="https://tcga-xena-hub.s3.us-east-1.amazonaws.com/latest/TCGA.UCS.sampleMap/HiSeqV2.gz", save_location=get_td_Home()+"data/downloaded/", delete_after=False, fetch_missing_hugo=True):
+def download_from_xena(url="https://tcga-xena-hub.s3.us-east-1.amazonaws.com/download/TCGA.UCS.sampleMap/HiSeqV2.gz", save_location=get_td_Home()+"data/downloaded/", delete_after=False, fetch_missing_hugo=True):
     """
     Function to download data directly from TCGA Xena Hub and read it in as a pandas df.
         Inputs:
@@ -154,12 +162,13 @@ def download_from_xena(url="https://tcga-xena-hub.s3.us-east-1.amazonaws.com/lat
     import os
 
     # Since all cancer types have the same filename, re-download every time:
-    zipfile = save_location+url.split('/')[-1]
+    zipfile = save_location+'/'+url.split('/')[-1]
     if os.path.exists(zipfile):
         os.remove(zipfile)
     # Download file and save it locally:
-    print("Downloading data from Xena Hub...")
+    print("Downloading data from Xena Hub to "+zipfile+"...")
     wget.download(url, save_location)
+    print()
     # pandas read_csv can handle the zipped file - no need to unzip
     # Read in data:
     logdf = read_rna_file(zipfile, fetch_missing_hugo=fetch_missing_hugo)
@@ -168,34 +177,7 @@ def download_from_xena(url="https://tcga-xena-hub.s3.us-east-1.amazonaws.com/lat
     return df
 
 
-# # OBSOLETE! Use read_sig_file() with no arguments to read in LM22.txt instead
-# def read_lm22_file(file_path=get_td_Home()+"data/LM22.txt"):
-#     """
-#     Read in the LM22 (or LM6) signature matrix file (containing signature gene expression data for 22 different cell types)
-#     and return a pandas dataframe
-#     Inputs:
-#         - file_path: string. Relative or full path to the LM22/LM6 signature matrix file
-#             This file is tab seperated. Columns are cell types, Rows are gene Hugo Symbols.
-#     Output:
-#         - pandas data frame. Columns are cell types, Rows are genes, indexed by Hugo Symbol.
-#     """
-#
-#     import pandas as pd
-#
-#     print("WARNING: 'read_lm22_file()'' depreciated. Use 'read_sig_file()' with no arguments to read in 'LM22.txt' signatures")
-#
-#     lm22 = pd.read_csv(file_path, sep='\t')
-#     # lm22['Hugo_Symbol'] = lm22['Gene symbol']
-#     # lm22 = lm22.drop(['Gene symbol'], axis = 1)
-#     new_column_names = lm22.columns.tolist()
-#     new_column_names[0] = 'Hugo_Symbol'
-#     lm22.columns = new_column_names
-#     lm22 = lm22.set_index(['Hugo_Symbol'])
-#
-#     return lm22
-
-
-def read_sig_file(file_path=get_td_Home()+"data/LM22.txt", geneID="Hugo_Symbol"):
+def read_sig_file(file_path=get_td_Home()+"data/LM22.txt", delim="\t", geneID="Hugo_Symbol"):
     """
     Reads in a signature matrix file (containing signature gene expression data for
     a number of different cell types), converts the gene identifiers to Hugo Symbols,
@@ -205,6 +187,7 @@ def read_sig_file(file_path=get_td_Home()+"data/LM22.txt", geneID="Hugo_Symbol")
         - file_path: string. Relative or full path to signature matrix file.
             This file is tab seperated. Columns are cell types, Rows are genes
             If no file_path given, LM22 is assumed.
+        - delim: String. Delimiter to use. Default is '\t' (tab separated)
         - geneID: string in ["Hugo_Symbol", "Ensembl_Gene_ID", "Entrez_Gene_ID"].
             Describes how genes are labeled in the signature matrix file
     Output:
@@ -213,7 +196,7 @@ def read_sig_file(file_path=get_td_Home()+"data/LM22.txt", geneID="Hugo_Symbol")
     import pandas as pd
 
     # Read file:
-    sig = pd.read_csv(file_path, sep='\t')
+    sig = pd.read_csv(file_path, sep=delim)
     # Get name of column with gene identifiers:
     gene_col = list(sig)[0]
 
@@ -465,7 +448,7 @@ def read_geneset(file_path=get_td_Home()+"data/LM22_up_genes.csv"):
         Function to read in a custom csv file containing the up or down regulated
             genes for each cell type
         Inputs:
-            - file_path: string. Relative or full path to signature matrix file.
+            - file_path: string. Relative or full path to csv file.
             File should have columns named for each cell type, and rows should
             contain Hugo Symbols for genes to be considered as up (or down)
             regulated for that cell type. If not all cell types have the same number of up(down)
